@@ -1,6 +1,10 @@
-from pyccuracy.selenium_browser_driver import *
+import os
+import sys
+sys.path.insert(0,os.path.abspath(__file__+"/../../../"))
+from pyccuracy.page import Page
 from pyccuracy.errors import *
-from action_base import *
+from pyccuracy.actions.action_base import ActionBase
+from pyccuracy.actions.element_is_visible_base import *
 
 class PageSeeTitleAction(ActionBase):
     def __init__(self, browser_driver, language):
@@ -14,8 +18,8 @@ class PageSeeTitleAction(ActionBase):
     def values_for(self, line):
         return self.last_match and (self.last_match.groups()[1],) or tuple([])
 
-    def execute(self, values):
+    def execute(self, values, context):
         expected_title = values[0]
         title = self.browser_driver.get_title()
         if (title != expected_title):
-            raise ActionFailedError(self.language["page_see_title_failure"] % (title, expected_title))
\ No newline at end of file
+            self.raise_action_failed_error(self.language["page_see_title_failure"] % (title, expected_title))
