@@ -27,5 +27,5 @@ class SelectHasSelectedValueAction(ActionBase):
         
         selected_value = self.browser_driver.get_selected_value(select)
 
-        if (str(selected_value) != str(value)):
+        if (unicode(selected_value) != unicode(value)):
             self.raise_action_failed_error(self.language["select_has_selected_value_failure"] % (select_name, value, selected_value))
