@@ -3,20 +3,24 @@ class TestFailedError(Exception):
         self.message = message
 
     def __str__(self):
-        return self.message
+        return unicode(self.message)
 
 class ActionFailedError(Exception):
     def __init__(self, message):
         self.message = message
 
     def __str__(self):
-        return self.message
+        return unicode(self.message)
         
 class InvalidScenarioError(Exception):
     def __init__(self, message):
         self.message = message
+        print message
 
     def __str__(self):
+        return unicode(self.message)
+        
+    def __unicode__(self):
         return self.message
         
 class LanguageParseError(Exception):
@@ -26,4 +30,15 @@ class LanguageParseError(Exception):
         self.file_path = file_path
 
     def __str__(self):
-        return self.error_message % (self.culture, self.file_path)
+        return unicode(self.error_message) % (self.culture, self.file_path)
+        
+class SelectOptionError(Exception):
+    def __init__(self, message):
+        self.message = message
+        print message
+
+    def __str__(self):
+        return unicode(self.message)
+        
+    def __unicode__(self):
+        return self.message
