@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 from errors import *
 import os
 import re
@@ -15,13 +17,14 @@ class Language(object):
         file_name = "language_" + culture + ".txt"
         file_path = os.path.join(self.languages_dir, file_name)
 
-        if not os.path.exists(file_path): raise LanguageParseError(culture, file_path)
+        if not os.path.exists(file_path):
+            raise LanguageParseError(culture, file_path)
+
         try:
-            fsock = open(file_path)
-            lines = [line.strip() for line in fsock.readlines() if line.strip() != ""]
-            fsock.close()
+            content = unicode(open(file_path).read(), encoding='utf-8')
+            lines = [line.strip() for line in content.split("\n") if len(line)]
         except ValueError:
-            raise LanguageParseError(culture)
+            raise LanguageParseError(culture, file_path)
 
         for line in lines:
             if not line.startswith("#"):
@@ -29,13 +32,13 @@ class Language(object):
                 key = key.strip()
                 value = value.strip()
                 if key.endswith("_regex"):
-                    value = re.compile(value)
+                    value = re.compile(value, re.U)
                 self.language_items[key.strip()] = value
 
-    def __getitem__(self, key): 
-        if self.language_items.has_key(key):
-            return self.language_items[key]
-        return None
+    def __getitem__(self, key):
+        item = self.language_items.get(key, None)
+        if item is None: raise LookupError("The key %s was not found in the language definitions." % key)
+        return item
 
 if __name__ == "__main__":
     lang = language()
